@@ -1,4 +1,4 @@
-utils::globalVariables(c("std.error", "conf.low", "conf.high", "datacol", "models", "avgpred"))
+utils::globalVariables(c("conf.low", "conf.high", "datacol", "models"))
 
 #' @rdname ggpredict
 #' @importFrom dplyr group_by_ summarise arrange_ mutate ungroup select_
@@ -9,14 +9,10 @@ utils::globalVariables(c("std.error", "conf.low", "conf.high", "datacol", "model
 ggaverage <- function(model, terms, ci.lvl = .95, type = c("fe", "re"), typical = c("mean", "median"), ...) {
   # get predictions for full data
   dat <- ggpredict(model, terms, ci.lvl, type, full.data = TRUE, typical, ...)
-  # and for unique data, to get proper SE / CI for plotting
-  dat2 <- ggpredict(model, terms, ci.lvl, type, full.data = FALSE, typical, ...)
-
 
   # remove columns with obs and resid
   dat <- dplyr::select_(dat, "-observed", "-residuals")
 
-
   # do summary, depending on third group
   if (tibble::has_name(dat, "facet")) {
     dat <- dplyr::group_by_(dat, "x", "group", "facet")
@@ -32,12 +28,11 @@ ggaverage <- function(model, terms, ci.lvl = .95, type = c("fe", "re"), typical
   # check if x is a factor. We can then simply take mean values for
   # standard error and confidence intervals. For continuous variables,
   # we have no linear trend for the predicted values, and hence no "proper"
-  # confidence bands that can be plotted with geom_ribbon. So we do some
-  # workaround in such cases (see below)
+  # confidence bands that can be plotted with geom_ribbon.
   if (x_is_factor) {
     zus <- get_average_values(dat)
   } else {
-    zus <- get_smoothed_avg(dat, dat2, ci.lvl)
+    zus <- get_smoothed_avg(dat)
   }
 
 
@@ -49,7 +44,7 @@ ggaverage <- function(model, terms, ci.lvl = .95, type = c("fe", "re"), typical
   # original data frame and delete the common attributes, like class etc.
   # and then add attributes to our final df
   a <- attributes(dplyr::ungroup(dat))
-  a[c("names","row.names","class","dim","dimnames")] <- NULL
+  a[c("names", "row.names", "class", "dim", "dimnames")] <- NULL
   attributes(zus) <- c(attributes(zus), a)
   # no full data for averages
   attr(zus, "full.data") <- "0"
@@ -77,7 +72,6 @@ get_average_values <- function(dat) {
   zus <- dplyr::summarise(
     dat,
     predicted = mean(predicted),
-    std.error = mean(std.error, na.rm = TRUE),
     conf.low = mean(conf.low, na.rm = TRUE),
     conf.high = mean(conf.high, na.rm = TRUE)
   ) %>%
@@ -85,9 +79,9 @@ get_average_values <- function(dat) {
 
   # sort columns
   if (tibble::has_name(dat, "facet")) {
-    zus <- zus[, c(1, 4:7, 2:3)]
+    zus <- zus[, c(1, 4:6, 2:3)]
   } else {
-    zus <- zus[, c(1, 3:6, 2)]
+    zus <- zus[, c(1, 3:5, 2)]
   }
 
   zus
@@ -96,53 +90,22 @@ get_average_values <- function(dat) {
 
 # this method prepares the data to get smoothed predictions for
 # average effects
-get_smoothed_avg <- function(dat, dat2, ci.lvl) {
+get_smoothed_avg <- function(dat) {
   # get average prediction. this is quite strait forward...
   zus <- dplyr::summarise(dat, predicted = mean(predicted)) %>% dplyr::ungroup()
 
-
-  # remove unused columns for 2nd data frame. we will bind some
-  # columns from this df to our final df
-  dat2 <- dplyr::select_(dat2, "-predicted", "-conf.low", "-conf.high")
-
-
-  # arrange columns, so we have equal row order in both data frames
-  # then, join data frames, so we have proper standard errors. we cannot
-  # average standard errors and conf. int. because of variation within groups.
-  # hence, we have no linear trend of predictions, nor for SE and CI. this
-  # would result in unproper CI-bands when plotting with geom_ribbon.
-  # so instead, we compute a regression on the predictions, based by the
-  # variable "x" (the same family and link function as in the orignal model),
-  # take the fitted values of predictions and compute the CI based on these
-  # values.
   if (tibble::has_name(dat, "facet")) {
-    zus <- dplyr::arrange_(zus, "x", "group", "facet")
-    dat2 <- dplyr::arrange_(dat2, "x", "group", "facet")
-    zus <- dplyr::left_join(zus, dat2, by = c("x", "group", "facet"))
-    zus <- dplyr::group_by_(zus, "group", "facet")
+    zus <- zus %>%
+      dplyr::arrange_("x", "group", "facet") %>%
+      dplyr::group_by_("group", "facet")
   } else {
-    zus <- dplyr::arrange_(zus, "x", "group")
-    dat2 <- dplyr::arrange_(dat2, "x", "group")
-    zus <- dplyr::left_join(zus, dat2, by = c("x", "group"))
-    zus <- dplyr::group_by_(zus, "group")
+    zus <- zus %>%
+      dplyr::arrange_("x", "group") %>%
+      dplyr::group_by_("group")
   }
 
-  get_smoothed_predictions(zus, dat, ci.lvl)
-}
 
-
-# this method computes the standard errors and confidence intervals
-# for continuous variables. since the averaged predicted values follow a specific
-# "trend" (linear, curvilinear), the standard errors and ci should do so, too.
-# however, due to different spread of data points, se and ci may follow a "zigzag" curve.
-# to prevent this, we "predict" the (curvi-)linear trend of the average predicted
-# values, and then take the standard errors from the marginal effects at the mean
-# and calculate ci manually. This allows us to plot a "geom_ribbon()", without
-# needing to use a smoother for the confidence bands.
-get_smoothed_predictions <- function(zus, dat, ci.lvl) {
-  # now we need to compute confidence intervals, by predicting
-  # values from the averaged predictions. This is how to get
-  # "smoothed" predictions from averages
+  # get family and link function, for smoother
   fam <- attr(dat, "family", exact = TRUE)
   link <- attr(dat, "link", exact = TRUE)
 
@@ -181,19 +144,8 @@ get_smoothed_predictions <- function(zus, dat, ci.lvl) {
     dplyr::ungroup()
 
 
-  # if user does not want CI, we don't need to compute the predictions
-  if (!is.null(ci.lvl) && !is.na(ci.lvl)) {
-    # bind std.error and CI to final data frame
-    zus <- zus %>%
-      dplyr::mutate(
-        conf.low = avgpred - stats::qnorm(.975) * std.error,
-        conf.high = avgpred + stats::qnorm(.975) * std.error
-      )
-  } else {
-    zus$std.error <- NA
-    zus$conf.low <- NA
-    zus$conf.high <- NA
-  }
+  zus$conf.low <- NA
+  zus$conf.high <- NA
 
   # remove standard predicted, and replace with avg predicted
   zus <- zus %>%
@@ -202,9 +154,9 @@ get_smoothed_predictions <- function(zus, dat, ci.lvl) {
 
   # re-arrange columns
   if (tibble::has_name(dat, "facet"))
-    zus <- zus[, c(4, 3, 5:7, 1:2)]
+    zus <- zus[, c(4, 3, 5:6, 1:2)]
   else
-    zus <- zus[, c(3, 2, 4:6, 1)]
+    zus <- zus[, c(3, 2, 4:5, 1)]
 
   zus
 }
